/*
 * Copyright (c) 1993 Richard V. Nash.
 * Copyright (c) 2000 Dan Papasian.  All rights reserved.
 *
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#define EXTERN
#include "includes.h"

static void usage(char *progname)
{
  d_printf( "Usage: %s [-l] [-n] UserName FullName EmailAddress\n", progname);
  exit(1);
}

/* Parameters */
static int local = 1;
static char *funame = NULL, *fname = NULL, *email = NULL;

#define PASSLEN 4
int main(int argc, char *argv[])
{
  int admin, i, ch;
  int p;
  char password[PASSLEN + 1];
  char salt[3];
  char *text;

  admin = 0;

  while((ch = getopt(argc, argv, "lna:")) != -1) {
	switch(ch) {
      	case 'l':
		local = 1;
		break;
    	case 'n':
		local = 0;
		break;
	case 'a':
		admin = atoi(optarg);
      }
  }

  funame = strdup(argv[argc-3]);
  fname = strdup(argv[argc-2]);
  email = strdup(argv[argc-1]);
  if (!funame || !fname || !email)
    usage(argv[0]);

  /* Add the player here */
  if (strlen(funame) >= MAX_LOGIN_NAME) {
    d_printf( "Player name is too long\n");
    exit(0);
  }
  if (strlen(funame) < 3) {
    d_printf( "Player name is too short\n");
    exit(0);
  }
  if (!alphastring(funame)) {
    d_printf( "Illegal characters in player name. Only A-Za-z allowed.\n");
    exit(0);
  }

/* loon: see if we can deliver mail to this email address. */
/*
  printf("Verifying email address %s...\n", email);
  if (check_emailaddr(email)) {
    d_printf( "The email address %s looks bad.\n", email);
    exit(0);
  }
*/
/*
  if (local)
    iamserver = 0;
  else
    iamserver = 1;
*/
/*  if (hostinfo_init()) {
    if (iamserver) {
      d_printf( "Can't read from hostinfo file.\n");
      d_printf( "Remember you need -l for local.\n");
      exit(1);
    } else {
    } 
  } */
  player_init(0);
  srandom(time(0));
  p = player_new();
  if (!player_read(p, funame)) {
    d_printf( "%s already exists.\n", funame);
    exit(0);
  }
  player_globals.parray[p].name = strdup(funame);
  player_globals.parray[p].login = strdup(funame);
  player_globals.parray[p].adminLevel = admin;

  stolower(player_globals.parray[p].login);
  player_globals.parray[p].fullName = strdup(fname);
  player_globals.parray[p].emailAddress = strdup(email);
  for (i = 0; i < PASSLEN; i++) {
    password[i] = 'a' + random() % 26;
  }
  password[i] = '\0';
  salt[0] = 'a' + random() % 26;
  salt[1] = 'a' + random() % 26;
  salt[2] = '\0';
  player_globals.parray[p].passwd = strdup(chessd_crypt(password,salt));
  PFlagON(p, PFLAG_REG);
/*  player_globals.parray[p].network_player = !local; */
  PFlagON(p, PFLAG_RATED);
  player_save(p);
/*  changed by Sparky  12/15/95  Dropped reference to 'Network' players
    and spiffed it up  */
/*
  printf("Added %s player >%s< >%s< >%s< >%s<\n", local ? "local" : "network",
	 funame, fname, email, password);
  rasprintf(&text, "\nYou have been added as a %s player.\nIf this is a network account it may take a while to show up on all of the\nclients.\n\nLogin Name: %s\nFull Name: %s\nEmail Address: %s\nInitial Password: %s\n\nIf any of this information is incorrect, please contact the administrator\nto get it corrected.\nPlease write down your password, as it will be your initial passoword\non all of the servers.\n", local ? "local" : "network", funame, fname, email, password);
*/

  printf("Added %s account: >%s< >%s< >%s< >%s<\n", 
	 admin?"ADMIN":"player",
         funame, fname, email, password);

  asprintf(&text, "\nYour player account has been created.\n\n"
   "Login Name: %s\nFull Name: %s\nEmail Address: %s\nInitial Password: %s\n\n"
   "If any of this information is incorrect, please contact the administrator\n"
   "to get it corrected.\n\n"
   "You may change your password with the password command on the the server.\n"
   "\nPlease be advised that if this is an unauthorized duplicate account for\n"
   "you, by using it you take the risk of being banned from accessing this\n"
   "chess server.\n\n"
   "Regards,\n\nThe FICS admins\n", 
        funame, fname, email, password);

  free(text);

  mail_string_to_address(email, "FICS Account Created", text);
  exit(0);
}
