/*-
 * Copyright (c) 2000 Dan Papasian.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include "includes.h"

enum { SEEKOPEN = 0, SEEKCLOSED };

/* The values of the follwing enums cannot be changed as they will end up */
/* Being seen by the client- we can add values later but the ones */
/* Here, after being documented, have to be here forever */
enum { LIGHTNING = 0, STANDARD, BLITZ, UNTIMED };
enum { UNRATED = 0, RATED};
#undef BLACK
#undef WHITE
enum { BLACK = 0, WHITE};


static int get_empty_seekslot(void);
static char *form_ad(pending * ad, int i);

int com_seek(int p, param_list param)
{
	int             p1, count = 0;
	int             num;	/* sought ID */
	char           *msgtxt;
	char		board[1], category[1];

	
	srandom(time(0));
#if 0
	if (!CheckPFlag(p, PFLAG_REG)) {
		pprintf(p, "Only registered players can use the seek command.\n");
		return COM_OK;
	}
#endif

	if ((player_globals.parray[p].game >= 0) && ((game_globals.garray[player_globals.parray[p].game].status == GAME_EXAMINE) || (game_globals.garray[player_globals.parray[p].game].status == GAME_SETUP))) {
		pprintf(p, "ERROR: You can't seek a game while you are examining one.\n");
		return COM_OK;
	}
	if (player_globals.parray[p].game >= 0) {
		pprintf(p, "ERROR: You can't seek a game while you are playing one.\n");
		return COM_OK;
	}
	num = get_empty_seekslot();
	if (num == -1) {
		pprintf(p, "ERROR: Sorry, all available slots for seek are closed.\n");
		return COM_OK;
	}
	seek_globals.ads[num].status = SEEKCLOSED;
	seek_globals.ads[num].whofrom = p;

	if (param[0].type == TYPE_INT)
		seek_globals.ads[num].param1 = param[0].val.integer;	/* White time */
	else
		seek_globals.ads[num].param1 = player_globals.parray[p].d_time;

	if (param[1].type == TYPE_INT)
		seek_globals.ads[num].param2 = param[1].val.integer;	/* White increment */
	else
		seek_globals.ads[num].param2 = player_globals.parray[p].d_inc;

	seek_globals.ads[num].param3 = seek_globals.ads[num].param1;	/* Black time */
	seek_globals.ads[num].param4 = seek_globals.ads[num].param2;	/* Black increment */

	if (param[2].type == TYPE_INT) {
		if (param[2].val.integer == UNRATED || !CheckPFlag(p, PFLAG_REG) || seek_globals.ads[num].param1 == 0)
			seek_globals.ads[num].param5 = UNRATED;	/* unrated */
		else if (param[2].val.integer == RATED)
			seek_globals.ads[num].param5 = RATED;	/* rated */
	} else
		seek_globals.ads[num].param5 = BoolCheckPFlag(p, PFLAG_RATED);


	if (param[3].type == TYPE_INT) {
		if (param[3].val.integer == WHITE)
			seek_globals.ads[num].param6 = WHITE;
		else if (param[3].val.word[0] == BLACK)
			seek_globals.ads[num].param6 = BLACK;
	} else
		seek_globals.ads[num].param6 = random() % 2;

	category[0]='\0';
	board[0]='\0';
	/* FIXME- use proper values */
	seek_globals.ads[num].char1 = strdup(category);
	seek_globals.ads[num].char2 = strdup(board);

	seek_globals.ads[num].next = NULL;
	seek_globals.ads[num].last = NULL;

	msgtxt = form_ad(&seek_globals.ads[num], num);

	for (p1 = 0; p1 < player_globals.p_num; p1++) {
		if ((p1 == p) || !CheckPFlag(p1, PFLAG_ADS)
		  || (player_globals.parray[p1].status != PLAYER_PROMPT)
		  || (player_censored(p1, p)))
			continue;
		count++;
		pprintf(p1, "%s", msgtxt);
	}
	pprintf(p, "%s", msgtxt);
	free(msgtxt);

	return COM_OK;
}

int com_play(int p, param_list param)
{
	int             game;

	game = param[0].val.integer;

	if (seek_globals.ads[game].status != SEEKCLOSED) {
		pprintf(p, "ERROR: Either that game has already started or "
			"it is no longer available.\n");
		return COM_OK;
	}
	if (!CheckPFlag(p, PFLAG_REG) && seek_globals.ads[game].param5 == 1) {
		pprintf(p, "ERROR: Unregistred users cannot play rated games.\n");
		return COM_OK;
	}
	if (seek_globals.ads[game].whofrom == p) {
		pprintf(p, "ERROR: You cannot respond to your own seek ads\n");
		return COM_OK;
	}
	seek_globals.ads[game].whoto = p;

	decline_withdraw_offers(p, -1, PEND_ALL, DO_DECLINE | DO_WITHDRAW); 
	decline_withdraw_offers(seek_globals.ads[game].whofrom, -1, PEND_ALL, DO_DECLINE | DO_WITHDRAW);

	accept_match(&seek_globals.ads[game], p, seek_globals.ads[game].whofrom);
#if 0
	free(seek_globals.ads[game].char1);
	free(seek_globals.ads[game].char2);
#endif
return 0;
}

int com_sought(int p, param_list param)
{
	int             i;

	for (i = 0; i <= MAXSOUGHT; ++i) {
		if (seek_globals.ads[i].status == SEEKCLOSED) {
			char *msgtxt = form_ad(&seek_globals.ads[i], i);
			pprintf(p, "%s", msgtxt);
			free(msgtxt);
		}
	}
	return COM_OK;
}


int com_unseek(int p, param_list param)
{
	/* TODO: need to add parameters */
	withdraw_seeks(p);
	return COM_OK;
}

void withdraw_seeks(int p)
{
	int             i, p1;

	for (i = 0; i <= MAXSOUGHT; i++) {
		if (seek_globals.ads[i].whofrom == p && seek_globals.ads[i].status == SEEKCLOSED) {
			seek_globals.ads[i].status = SEEKOPEN;

			for (p1 = 0; p1 < player_globals.p_num; p1++) {
				if ((p1 == p) || (player_globals.parray[p1].status != PLAYER_PROMPT) ||
				    (player_censored(p1, p)) || !CheckPFlag(p1,PFLAG_ADS))
					continue;
				pprintf_prompt(p1, "AD_DESTROY: %d\n", i);
			}
			pprintf(p, "AD_DESTROY: %d\n", i);
#if 0
			free(seek_globals.ads[i].char1);
			free(seek_globals.ads[i].char2);
#endif

		}
	}
}

static int
get_empty_seekslot(void)
{
	int             i;

	for (i = 0; i <= MAXSOUGHT; i++) {
		if (seek_globals.ads[i].status != SEEKCLOSED)
			return i;
	}

	return -1;
}

static char *form_ad(pending * ad, int i)
{

	char           *final;
	int             rating, total, type;

	total = ad->param1 * 60 + ad->param2 * 40;

	if(total == 0) {
		type = UNTIMED;
		rating = player_globals.parray[ad->whofrom].l_stats.rating;
        } else if (total < 180) {
                type = LIGHTNING;
                rating = player_globals.parray[ad->whofrom].l_stats.rating;
        } else if (total >= 900) {
                type = STANDARD; 
                rating = player_globals.parray[ad->whofrom].s_stats.rating;
        } else {
                type = BLITZ;
                rating = player_globals.parray[ad->whofrom].b_stats.rating;
	}

	asprintf(&final, "%3u %4u %-17s %3u %3u %-7s %-10s\n",
		 i, 
		 rating,
		 player_globals.parray[ad->whofrom].name, 
		 ad->param1, 
		 ad->param2, 
		 ad->param5?"rated":"unrated",
		 TypeStrings[ad->param6]);

	return final;
}
